==> qlcplus_4.13.1.orig.tar.xz: qlcplus-QLC-_4.13.1/plugins/udmx/src/uDMX_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>UDMX</name>
    <message>
        <location filename="udmx.cpp" line="100"/>
        <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
        <translation>Dieses Plugin bietet DMX-Output für Anyma uDMX Geräte.</translation>
    </message>
    <message>
        <location filename="udmx.cpp" line="199"/>
        <source>Do you wish to re-scan your hardware?</source>
        <translation>Nach neuer Hardware suchen?</translation>
    </message>
</context>
<context>
    <name>UDMXDevice</name>
    <message>
        <location filename="udmxdevice.cpp" line="122"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="142"/>
        <source>Device name</source>
        <translation>Gerätename</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="144"/>
        <source>DMX Channels</source>
        <translation>DMX Kanäle</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="146"/>
        <source>DMX Frame Frequency</source>
        <translation>DMX-Rahmen-Frequenz</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="149"/>
        <source>Bad</source>
        <translation>Schlecht</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="151"/>
        <source>Good</source>
        <translation>Gut</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="153"/>
        <source>Patch this device to a universe to find out.</source>
        <translation>Patche dieses Gerät zu einem herauszufindendem Universum.</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="154"/>
        <source>System Timer Accuracy</source>
        <translation>System-Timer Genauigkeit</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="159"/>
        <source>Device not in use</source>
        <translation>Gerät nicht in Verwendung</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.3.orig.tar.xz: qlcplus-QLC-_4.14.3/plugins/udmx/src/uDMX_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>UDMX</name>
    <message>
        <location filename="udmx.cpp" line="100"/>
        <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
        <translation>Dieses Plugin bietet DMX-Output für Anyma uDMX Geräte.</translation>
    </message>
    <message>
        <location filename="udmx.cpp" line="199"/>
        <source>Do you wish to re-scan your hardware?</source>
        <translation>Nach neuer Hardware suchen?</translation>
    </message>
</context>
<context>
    <name>UDMXDevice</name>
    <message>
        <location filename="udmxdevice.cpp" line="122"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="142"/>
        <source>Device name</source>
        <translation>Gerätename</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="144"/>
        <source>DMX Channels</source>
        <translation>DMX Kanäle</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="146"/>
        <source>DMX Frame Frequency</source>
        <translation>DMX-Rahmen-Frequenz</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="149"/>
        <source>Bad</source>
        <translation>Schlecht</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="151"/>
        <source>Good</source>
        <translation>Gut</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="153"/>
        <source>Patch this device to a universe to find out.</source>
        <translation>Patche dieses Gerät zu einem herauszufindenden Universum.</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="154"/>
        <source>System Timer Accuracy</source>
        <translation>System-Timer-Genauigkeit</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="159"/>
        <source>Device not in use</source>
        <translation>Gerät nicht in Verwendung</translation>
    </message>
</context>
</TS>
